"""Cataloging and searching components for access codes.
"""
import grok
from grok import index
from hurry.query import Eq, Text
from hurry.query.query import Query
from zope.index.text.parsetree import ParseError
from waeup.sirp.interfaces import IUniversity, IQueryResultItem
from waeup.sirp.accesscodes.interfaces import IAccessCode

class AccessCodeIndexes(grok.Indexes):
    """A catalog for access codes.
    """
    grok.site(IUniversity)
    grok.name('accesscodes_catalog')
    grok.context(IAccessCode)

    code = index.Field(attribute='representation')
    history = index.Text(attribute='history')
    batch_serial = index.Field(attribute='batch_serial')
    state = index.Field(attribute='state')

class AccessCodeQueryResultItem(object):
    grok.implements(IQueryResultItem)

    title = u'Access Code Query Item'
    description = u'Some access code found in a search'

    def __init__(self, context, view):
        self.context = context
        self.url = view.url(context)
        self.code = context.representation
        self.history = context.history
        self.state = context.state
        self.owner = context.owner
        self.batch_serial = context.batch_serial

def search(query=None, searchtype=None, view=None):
    if not query:
        view.flash('Empty search string.')
        return
    hitlist = []
    if searchtype == 'history':
        results = Query().searchResults(
            Text(('accesscodes_catalog', searchtype), query))
    elif searchtype == 'batch_serial':
        results = Query().searchResults(
            Eq(('accesscodes_catalog', searchtype), int(query)))
    else:
        results = Query().searchResults(
            Eq(('accesscodes_catalog', searchtype), query))
    for result in results:
        hitlist.append(AccessCodeQueryResultItem(result, view=view))
    return hitlist
